@@ -5,7 +5,7 @@ import pandas as pd
 import os
 from time import sleep
 
-versionNo = "0.1.3"
+versionNo = "0.1.5"
 
 controlEndpoint = "tcp://127.0.0.1:5557"
 dataEndpoint = "tcp://127.0.0.1:5556"
@@ -147,7 +147,8 @@ class heat():
             timeOrRate : rampTimeRate    
             }
         returnMessage = sendControl(controlDict)
-        self.busy = True
+        if returnMessage["resultCode"] =="ok":
+            self.busy = True
         return returnMessage["resultCode"]        
 
     def stopRamp(self):
@@ -186,7 +187,8 @@ class bias():
             'compliance' : compliance            
             }
         returnMessage = sendControl(controlDict)
-        self.busy = True
+        if returnMessage["resultCode"] =="ok":
+            self.busy = True
         return returnMessage["resultCode"]
 
     def stopSweepCycle(self):
@@ -269,7 +271,8 @@ class gas():
             controlDict['gas3Flow']=gas3Flow
             controlDict['gas3FlowPath']=gas3FlowPath           
         returnMessage = sendControl(controlDict)
-        self.busy = True
+        if returnMessage["resultCode"] =="ok":
+            self.busy = True
         return returnMessage["resultCode"]
     
     def setIOP(self, inletPressure, outletPressure, gas1Flow=None, gas1FlowPath=None, gas2Flow=None, gas2FlowPath=None, gas3Flow=None, gas3FlowPath=None):
@@ -290,7 +293,8 @@ class gas():
             controlDict['gas1Concentration']=gas1Concentration
             controlDict['gas2Concentration']=gas2Concentration        
         returnMessage = sendControl(controlDict)
-        self.busy = True
+        if returnMessage["resultCode"] =="ok":
+            self.busy = True
         return returnMessage["resultCode"]    
     
     def setPF(self, reactorPressure, reactorFlow, gasConcentrationType=None, gas1Concentration=None, gas2Concentration=None):
@@ -340,11 +344,11 @@ class eventHandler():
             contents = json.loads(contents)
             self.lastMssg = contents
             if contents["$type"]=="data.event.stimulusActionFinished": #vergeten hoe die heette
-                if contents["stimulus"]=="heat":
+                if contents["stimulusType"]=="heat":
                     heat.busy = False
-                if contents["stimulus"]=="bias":
+                if contents["stimulusType"]=="bias":
                     bias.busy = False
-                if contents["stimulus"]=="gas":
+                if contents["stimulusType"]=="gas":
                     gas.busy = False
             if contents["$type"] == "data.event.profileController.stateChanged": #deze moet ook anders heten
                 print("[PROFILE CONTROLLER]:",contents['state'])
@@ -392,7 +396,12 @@ class dataHandler():
             while True:
                 if self.event.is_set():
                     break
-                [address, contents] = self.dataSock.recv_multipart()
+                message = self.dataSock.recv_multipart()
+                if len(message)!=2:
+                    print("Not a multipart message!")
+                    print(message)
+                address = message[0]
+                contents = message [1]
                 contents = json.loads(contents)
                 contents["flags"]=self.currentFlag
                 self.lastMssg = contents
@@ -492,4 +501,4 @@ profile = profile()
 heat = heat()
 bias = bias()
 gas = gas()
-events = eventHandler()
\ No newline at end of file
+events = eventHandler()
